@@ -5,13 +5,15 @@
 #' @param slices Slices to take for the image voi
 #' @param na.rm Remove NAs from mean.  This is for double checking
 #' @param ... Arguments passed from other methods (not used)
+#' @import methods
 #' @export
 #' @return VOI of image.
 make_img_voi = function(img, slices = 80:120, na.rm = TRUE, ...){
   if (inherits(img, "img_voi")){
     return(img)
   }
-  img.voi = img[,,slices]  
+  img = as.array(img)
+  img.voi = img[,,slices]
   mn = mean(img, na.rm=na.rm)
   img.voi = img.voi[ img.voi > mn]
   if (na.rm) img.voi = img.voi[!is.na(img.voi)]
@@ -76,7 +78,7 @@ whitestripe = function(img, type=c("T1", "T2", "last", "largest"), breaks=2000,
   y.in = y.in[!is.na(y.in)]
   
   stopifnot(length(type) == 1)
-  type = match.arg(type)
+  type = match.arg(type, choices = c("T1", "T2", "last", "largest"))
   if (verbose){
     cat(paste0("Getting ", type, " Modes\n"))
   }  
@@ -144,11 +146,15 @@ whitestripe = function(img, type=c("T1", "T2", "last", "largest"), breaks=2000,
 #' @description Taking the indices from white stripe to normalize the 
 #' intensity values of the brain
 #' @param img Array or object of class nifti
-#' @param indices Indices of white stripe from \code{\link{whitestripe}}
+#' @param indices Indices of white stripe from \code{\link{whitestripe}}. 
+#' Can also be a mask (indices where mask > 0 are used.)
 #' @param ... arguments to be passed to \code{\link{mean}} and \code{\link{sd}}
 #' @export
 #' @return Object of same class as img, but normalized
 whitestripe_norm = function(img, indices, ...){
+  if (inherits(indices, "nifti")){
+    indices = which(indices > 0)
+  }
   mu = mean(img[indices], ...)
   sig = sd(img[indices], ...)
   img = (img-mu)/sig
@@ -210,8 +216,9 @@ whitestripe_hybrid = function(t1, t2, ...){
 #' @seealso whitestripe, whitestripe_hybrid
 #' @return Class of array or nifti depending on img input
 #' @aliases whitemask
-#' @import fslr
 #' @importFrom oro.nifti writeNIfTI
+#' @importFrom oro.nifti cal_img
+#' @importFrom oro.nifti zero_trans
 #' @examples 
 #' \dontrun{
 #' if (download_img_data()){ 
